@@ -2,6 +2,7 @@
 
 namespace Icinga\Module\Director\Controllers;
 
+use gipfl\Web\Widget\Hint;
 use ipl\Html\Html;
 use gipfl\IcingaWeb2\Link;
 use gipfl\IcingaWeb2\Url;
@@ -116,16 +117,40 @@ class HostController extends ObjectController
      */
     public function invalidserviceAction()
     {
-        $this->content()->add(
-            Html::tag('p', ['class' => 'error'], sprintf(
+        if (! $this->showInfoForNonDirectorService()) {
+            $this->content()->add(Hint::error(sprintf(
                 $this->translate('No such service: %s'),
                 $this->params->get('service')
-            ))
-        );
+            )));
+        }
 
         $this->servicesAction();
     }
 
+    protected function showInfoForNonDirectorService()
+    {
+        try {
+            $api = $this->getApiIfAvailable();
+            if ($api) {
+                $name = $this->params->get('name') . '!' . $this->params->get('service');
+                $info = $api->getObject($name, 'Services');
+                if (isset($info->attrs->source_location)) {
+                    $source = $info->attrs->source_location;
+                    $this->content()->add(Hint::info(Html::sprintf(
+                        'The configuration for this object has not been rendered by'
+                        . ' Icinga Director. You can find it on line %s in %s.',
+                        Html::tag('strong', null, $source->first_line),
+                        Html::tag('strong', null, $source->path)
+                    )));
+                }
+            }
+
+            return true;
+        } catch (Exception $e) {
+            return false;
+        }
+    }
+
     /**
      * @throws \Icinga\Exception\NotFoundError
      */
@@ -143,16 +168,6 @@ class HostController extends ObjectController
             $content->add($table);
         }
 
-        if ($applied = $host->vars()->get($db->settings()->magic_apply_for)) {
-            if ($applied instanceof CustomVariableDictionary) {
-                $table = IcingaHostAppliedForServiceTable::load($host, $applied)
-                    ->setTitle($this->translate('Generated from host vars'));
-                if (count($table)) {
-                    $content->add($table);
-                }
-            }
-        }
-
         /** @var IcingaHost[] $parents */
         $parents = IcingaTemplateRepository::instanceByObject($this->object)
             ->getTemplatesFor($this->object, true);
@@ -221,19 +236,6 @@ class HostController extends ObjectController
             $content->add($table);
         }
 
-        /* @deprecated to be removed in 1.8.0 #1850 #1851 */
-        if ($applied = $host->vars()->get($db->settings()->magic_apply_for)) {
-            if ($applied instanceof CustomVariableDictionary) {
-                $table = IcingaHostAppliedForServiceTable::load($host, $applied)
-                    ->setReadonly()
-                    ->highlightService($service)
-                    ->setTitle($this->translate('Generated from host vars'));
-                if (count($table)) {
-                    $content->add($table);
-                }
-            }
-        }
-
         /** @var IcingaHost[] $parents */
         $parents = IcingaTemplateRepository::instanceByObject($this->object)
             ->getTemplatesFor($this->object, true);
