@@ -79,16 +79,22 @@ class SelfServiceController extends ActionController
             } else {
                 $error = implode('; ', $form->getErrorMessages());
                 if ($error === '') {
-                    foreach ($form->getErrors() as $elName => $errors) {
-                        if (in_array('isEmpty', $errors)) {
+                    if ($form->isMissingRequiredFields()) {
+                        $fields = $form->listMissingRequiredFields();
+                        if (count($fields) === 1) {
                             $this->sendPowerShellError(
-                                sprintf("%s is required", $elName),
+                                sprintf("%s is required", $fields[0]),
                                 400
                             );
-                            return;
                         } else {
-                            $this->sendPowerShellError('An unknown error ocurred', 500);
+                            $this->sendPowerShellError(
+                                sprintf("Missing parameters: %s", implode(', ', $fields)),
+                                400
+                            );
                         }
+                        return;
+                    } else {
+                        $this->sendPowerShellError('An unknown error ocurred', 500);
                     }
                 } else {
                     $this->sendPowerShellError($error, 400);
@@ -171,13 +177,12 @@ class SelfServiceController extends ActionController
      */
     protected function sendPowerShellError($error, $code)
     {
-        $this->getResponse()->setHttpResponseCode($code);
         if ($this->getRequest()->getHeader('X-Director-Accept') === 'text/plain') {
+            $this->getResponse()->setHttpResponseCode($code);
             echo "ERROR: $error";
         } else {
-            $this->sendJsonError($this->getResponse(), $error);
+            $this->sendJsonError($this->getResponse(), $error, $code);
         }
-        exit;
     }
 
     /**
@@ -263,7 +268,16 @@ class SelfServiceController extends ActionController
             'fetch_agent_name'    => $settings->get('self-service/agent_name') === 'hostname',
             'fetch_agent_fqdn'    => $settings->get('self-service/agent_name') === 'fqdn',
             'transform_hostname'  => $transform,
-            'flush_api_directory' => $settings->get('self-service/flush_api_dir') === 'y'
+            'flush_api_directory' => $settings->get('self-service/flush_api_dir') === 'y',
+            // ConvertEndpointIPConfig:
+            'resolve_parent_host' => $settings->get('self-service/resolve_parent_host'),
+            // InstallFrameworkService:
+            'install_framework_service' => '0',
+            // ServiceDirectory    => framework_service_directory
+            // FrameworkServiceUrl => framework_service_url
+            // InstallFrameworkPlugins:
+            'install_framework_plugins' => '0',
+            // PluginsUrl => framework_plugins_url
         ];
         $username = $settings->get('self-service/icinga_service_user');
         if (strlen($username)) {
@@ -336,7 +350,7 @@ class SelfServiceController extends ActionController
      * @throws \Zend_Controller_Request_Exception
      * @throws \Zend_Controller_Response_Exception
      */
-    protected function addHostToParams(IcingaHost $host, array & $params)
+    protected function addHostToParams(IcingaHost $host, array &$params)
     {
         if (! $host->isObject()) {
             return;
@@ -391,7 +405,7 @@ class SelfServiceController extends ActionController
         $params['accept_config']    = $host->getSingleResolvedProperty('accept_config')=== 'y';
     }
 
-    protected function addStringSettingsToParams(Settings $settings, array $keys, array & $params)
+    protected function addStringSettingsToParams(Settings $settings, array $keys, array &$params)
     {
         foreach ($keys as $key) {
             $value = $settings->get("self-service/$key");
@@ -401,7 +415,7 @@ class SelfServiceController extends ActionController
         }
     }
 
-    protected function addBooleanSettingsToParams(Settings $settings, array $keys, array & $params)
+    protected function addBooleanSettingsToParams(Settings $settings, array $keys, array &$params)
     {
         foreach ($keys as $key) {
             $value = $settings->get("self-service/$key");
