@@ -11,8 +11,8 @@ use Icinga\Module\Director\Objects\IcingaHost;
 use Icinga\Module\Director\Web\Form\DirectorObjectForm;
 use Icinga\Module\Director\Web\Table\IcingaAppliedServiceTable;
 use Icinga\Web\Widget\Tab;
-use dipl\Html\Link;
-use dipl\Web\Widget\Tabs;
+use gipfl\IcingaWeb2\Link;
+use gipfl\IcingaWeb2\Widget\Tabs;
 
 class ServiceController extends ObjectController
 {
@@ -32,6 +32,8 @@ class ServiceController extends ObjectController
     {
         if ($host = $this->params->get('host')) {
             $this->host = IcingaHost::load($host, $this->db());
+        } elseif ($hostId = $this->params->get('host_id')) {
+            $this->host = IcingaHost::loadWithAutoIncId($hostId, $this->db());
         } elseif ($set = $this->params->get('set')) {
             $this->set = IcingaServiceSet::load(['object_name' => $set], $this->db());
         } elseif ($apply = $this->params->get('apply')) {
@@ -71,7 +73,7 @@ class ServiceController extends ObjectController
             $tabs->add('set', [
                 'url'       => 'director/serviceset',
                 'urlParams' => ['name' => $setName],
-                'label'     => $this->translate('Serviceset'),
+                'label'     => $this->translate('ServiceSet'),
             ])->add('services', [
                 'url'       => 'director/serviceset/services',
                 'urlParams' => ['name' => $setName],
