@@ -9,11 +9,13 @@ use Icinga\Module\Director\Db;
 use Icinga\Module\Director\Deployment\DeploymentInfo;
 use Icinga\Module\Director\IcingaConfig\IcingaConfig;
 use Icinga\Module\Director\Web\Form\DirectorForm;
-use dipl\Html\Icon;
+use gipfl\IcingaWeb2\Icon;
 use Zend_View_Interface;
 
 class DeploymentLinkForm extends DirectorForm
 {
+    use DeployFormsBug7530;
+
     /** @var DeploymentInfo */
     protected $info;
 
@@ -82,10 +84,17 @@ class DeploymentLinkForm extends DirectorForm
 
         $this->setAttrib('class', 'inline');
         $this->addHtml(Icon::create('wrench'));
+        try {
+            // As this is shown for single objects, ignore errors caused by an
+            // unreachable core
+            $target = $this->shouldWarnAboutBug7530() ? '_self' : '_next';
+        } catch (\Exception $e) {
+            $target = '_next';
+        }
         $this->addSubmitButton($this->translate('Deploy'), [
             'class'            => 'link-button icon-wrench',
             'title'            => $msg,
-            'data-base-target' => '_next'
+            'data-base-target' => $target,
         ]);
     }
 
@@ -105,6 +114,13 @@ class DeploymentLinkForm extends DirectorForm
 
     public function onSuccess()
     {
+        try {
+            if ($this->skipBecauseOfBug7530()) {
+                return;
+            }
+        } catch (\Exception $e) {
+            // continue
+        }
         $this->deploy();
     }
 
