@@ -15,6 +15,8 @@ class IcingaCloneObjectForm extends DirectorForm
     /** @var IcingaObject */
     protected $object;
 
+    protected $baseObjectUrl;
+
     public function setup()
     {
         $name = $this->object->getObjectName();
@@ -93,6 +95,13 @@ class IcingaCloneObjectForm extends DirectorForm
         );
     }
 
+    public function setObjectBaseUrl($url)
+    {
+        $this->baseObjectUrl = $url;
+
+        return $this;
+    }
+
     public function onSuccess()
     {
         $object = $this->object;
@@ -195,7 +204,7 @@ class IcingaCloneObjectForm extends DirectorForm
                 );
             } else {
                 $this->setSuccessUrl(
-                    'director/' . strtolower($type),
+                    $this->baseObjectUrl ?: 'director/' . strtolower($type),
                     $new->getUrlParams()
                 );
             }
