@@ -69,6 +69,11 @@ abstract class DbObject
      */
     protected $autoincKeyName;
 
+    /** @var bool forbid updates to autoinc values */
+    protected $protectAutoinc = true;
+
+    protected $binaryProperties = [];
+
     /**
      * Filled with object instances when prefetchAll is used
      */
@@ -102,27 +107,27 @@ abstract class DbObject
         return $this->table;
     }
 
+    /************************************************************************\
+     * When extending this class one might want to override any of the      *
+     * following hooks. Try to use them whenever possible, especially       *
+     * instead of overriding other essential methods like store().          *
+    \************************************************************************/
+
     /**
-     * Kann überschrieben werden, um Kreuz-Checks usw vor dem Speichern durch-
-     * zuführen - die Funktion ist aber public und erlaubt jederzeit, die Kon-
-     * sistenz eines Objektes bei bedarf zu überprüfen.
+     * One can override this to allow for cross checks and more before storing
+     * the object. Please note that the method is public and allows to check
+     * object consistence at any time.
      *
-     * @return boolean  Ob der Wert gültig ist
+     * @return boolean  Whether this object is valid
      */
     public function validate()
     {
         return true;
     }
 
-    /************************************************************************\
-     * Nachfolgend finden sich ein paar Hooks, die bei Bedarf überschrieben *
-     * werden können. Wann immer möglich soll darauf verzichtet werden,     *
-     * andere Funktionen (wie z.B. store()) zu überschreiben.               *
-    \************************************************************************/
-
     /**
-     * Wird ausgeführt, bevor die eigentlichen Initialisierungsoperationen
-     * (laden von Datenbank, aus Array etc) starten
+     * This is going to be executed before any initialization method takes *
+     * (load from DB, populate from Array...) takes place
      *
      * @return void
      */
@@ -131,18 +136,8 @@ abstract class DbObject
     }
 
     /**
-     * Wird ausgeführt, nachdem mittels ::factory() ein neues Objekt erstellt
-     * worden ist.
-     *
-     * @return void
-     */
-    protected function onFactory()
-    {
-    }
-
-    /**
-     * Wird ausgeführt, nachdem mittels ::factory() ein neues Objekt erstellt
-     * worden ist.
+     * Will be executed every time an object has successfully been loaded from
+     * Database
      *
      * @return void
      */
@@ -151,8 +146,9 @@ abstract class DbObject
     }
 
     /**
-     * Wird ausgeführt, bevor ein Objekt abgespeichert wird. Die Operation
-     * wird aber auf jeden Fall durchgeführt, außer man wirft eine Exception
+     * Will be executed before an Object is going to be stored. In case you
+     * want to prevent the store() operation from taking place, please throw
+     * an Exception.
      *
      * @return void
      */
@@ -272,14 +268,28 @@ abstract class DbObject
             // There is getId, would give false positive
             return false;
         }
+
+        return $this->hasGetterForProperty($key);
+    }
+
+    protected function hasGetterForProperty($key)
+    {
         $func = 'get' . ucfirst($key);
-        if (substr($func, -2) === '[]') {
+        if (\substr($func, -2) === '[]') {
             $func = substr($func, 0, -2);
         }
-        if (method_exists($this, $func)) {
-            return true;
+
+        return \method_exists($this, $func);
+    }
+
+    protected function hasSetterForProperty($key)
+    {
+        $func = 'set' . ucfirst($key);
+        if (\substr($func, -2) === '[]') {
+            $func = substr($func, 0, -2);
         }
-        return false;
+
+        return \method_exists($this, $func);
     }
 
     /**
@@ -321,7 +331,7 @@ abstract class DbObject
 
         if (! $this->hasProperty($key)) {
             throw new InvalidArgumentException(sprintf(
-                'Trying to set invalid key %s',
+                'Trying to set invalid key "%s"',
                 $key
             ));
         }
@@ -457,7 +467,11 @@ abstract class DbObject
         $props = array();
         foreach (array_keys($this->modifiedProperties) as $key) {
             if ($key === $this->autoincKeyName) {
-                continue;
+                if ($this->protectAutoinc) {
+                    continue;
+                } elseif ($this->properties[$key] === null) {
+                    continue;
+                }
             }
 
             $props[$key] = $this->properties[$key];
@@ -536,18 +550,22 @@ abstract class DbObject
      *
      * // TODO: may conflict with ->id
      *
+     * @throws InvalidArgumentException When key can not be calculated
+     *
      * @return string|array
      */
     public function getId()
     {
-        // TODO: Doesn't work for array() / multicol key
         if (is_array($this->keyName)) {
             $id = array();
             foreach ($this->keyName as $key) {
-                if (! isset($this->properties[$key])) {
-                    return null; // Really?
+                if (isset($this->properties[$key])) {
+                    $id[$key] = $this->properties[$key];
                 }
-                $id[$key] = $this->properties[$key];
+            }
+
+            if (empty($id)) {
+                throw new InvalidArgumentException('Could not evaluate id for multi-column object!');
             }
 
             return $id;
@@ -733,12 +751,14 @@ abstract class DbObject
     {
         $properties = $this->getPropertiesForDb();
         if ($this->autoincKeyName !== null) {
-            unset($properties[$this->autoincKeyName]);
+            if ($this->protectAutoinc || $properties[$this->autoincKeyName] === null) {
+                unset($properties[$this->autoincKeyName]);
+            }
         }
         // TODO: Remove this!
         if ($this->connection->isPgsql()) {
             foreach ($properties as $key => $value) {
-                if (preg_match('/checksum$/', $key)) {
+                if ($this->isBinaryColumn($key)) {
                     $properties[$key] = Util::pgBinEscape($value);
                 }
             }
@@ -747,6 +767,11 @@ abstract class DbObject
         return $this->db->insert($this->table, $properties);
     }
 
+    protected function isBinaryColumn($column)
+    {
+        return in_array($column, $this->binaryProperties);
+    }
+
     /**
      * Store object to database
      *
@@ -775,7 +800,6 @@ abstract class DbObject
         $this->beforeStore();
         $table = $this->table;
         $id = $this->getId();
-        $result = false;
 
         try {
             if ($this->hasBeenLoadedFromDb()) {
@@ -791,15 +815,20 @@ abstract class DbObject
                 }
             } else {
                 if ($id && $this->existsInDb()) {
+                    $logId = '"' . $this->getLogId() . '"';
+
+                    if ($autoId = $this->getAutoincId()) {
+                        $logId .= sprintf(', %s=%s', $this->autoincKeyName, $autoId);
+                    }
                     throw new DuplicateKeyException(
                         'Trying to recreate %s (%s)',
                         $table,
-                        $this->getLogId()
+                        $logId
                     );
                 }
 
                 if ($this->insertIntoDb()) {
-                    if ($this->autoincKeyName) {
+                    if ($this->autoincKeyName && $this->getProperty($this->autoincKeyName) === null) {
                         if ($this->connection->isPgsql()) {
                             $this->properties[$this->autoincKeyName] = $this->db->lastInsertId(
                                 $table,
@@ -891,6 +920,12 @@ abstract class DbObject
     public function createWhere()
     {
         if ($id = $this->getAutoincId()) {
+            if ($originalId = $this->getOriginalProperty($this->autoincKeyName)) {
+                return $this->db->quoteInto(
+                    sprintf('%s = ?', $this->autoincKeyName),
+                    $originalId
+                );
+            }
             return $this->db->quoteInto(
                 sprintf('%s = ?', $this->autoincKeyName),
                 $id
@@ -906,19 +941,13 @@ abstract class DbObject
                     if ($this->loadedProperties[$k] === null) {
                         $where[] = sprintf('%s IS NULL', $k);
                     } else {
-                        $where[] = $this->db->quoteInto(
-                            sprintf('%s = ?', $k),
-                            $this->loadedProperties[$k]
-                        );
+                        $where[] = $this->createQuotedWhere($k, $this->loadedProperties[$k]);
                     }
                 } else {
                     if ($this->properties[$k] === null) {
                         $where[] = sprintf('%s IS NULL', $k);
                     } else {
-                        $where[] = $this->db->quoteInto(
-                            sprintf('%s = ?', $k),
-                            $this->properties[$k]
-                        );
+                        $where[] = $this->createQuotedWhere($k, $this->properties[$k]);
                     }
                 }
             }
@@ -926,19 +955,30 @@ abstract class DbObject
             return implode(' AND ', $where);
         } else {
             if ($this->hasBeenLoadedFromDb()) {
-                return $this->db->quoteInto(
-                    sprintf('%s = ?', $key),
-                    $this->loadedProperties[$key]
-                );
+                return $this->createQuotedWhere($key, $this->loadedProperties[$key]);
             } else {
-                return $this->db->quoteInto(
-                    sprintf('%s = ?', $key),
-                    $this->properties[$key]
-                );
+                return $this->createQuotedWhere($key, $this->properties[$key]);
             }
         }
     }
 
+    protected function createQuotedWhere($column, $value)
+    {
+        return $this->db->quoteInto(
+            sprintf('%s = ?', $column),
+            $this->eventuallyQuoteBinary($value, $column)
+        );
+    }
+
+    protected function eventuallyQuoteBinary($value, $column)
+    {
+        if ($this->isBinaryColumn($column)) {
+            return $this->connection->quoteBinary($value);
+        } else {
+            return $value;
+        }
+    }
+
     protected function getLogId()
     {
         $id = $this->getId();
@@ -948,6 +988,10 @@ abstract class DbObject
             $logId = $id;
         }
 
+        if ($logId === null && $this->autoincKeyName) {
+            $logId = $this->getAutoincId();
+        }
+
         return $logId;
     }
 
