@@ -40,6 +40,7 @@ class BasketSnapshot extends DbObject
         'IcingaTemplateChoiceService' => IcingaTemplateChoiceService::class,
         'ServiceTemplate' => IcingaService::class,
         'ServiceSet'      => IcingaServiceSet::class,
+        'NotificationTemplate' => IcingaNotification::class,
         'Notification'    => IcingaNotification::class,
         'DataList'        => DirectorDatalist::class,
         'Dependency'      => IcingaDependency::class,
@@ -72,6 +73,7 @@ class BasketSnapshot extends DbObject
         'IcingaTemplateChoiceService',
         'ServiceTemplate',
         'ServiceSet',
+        'NotificationTemplate',
         'Notification',
         'Dependency',
         'ImportSource',
@@ -258,7 +260,7 @@ class BasketSnapshot extends DbObject
      * @throws \Zend_Db_Adapter_Exception
      */
     protected function restoreType(
-        & $all,
+        &$all,
         $typeName,
         BasketSnapshotFieldResolver $fieldResolver,
         Db $connection,
@@ -314,7 +316,7 @@ class BasketSnapshot extends DbObject
      * @param $list
      * @throws \Icinga\Module\Director\Exception\DuplicateKeyException
      */
-    protected function recursivelyStore(IcingaObject $object, & $list)
+    protected function recursivelyStore(IcingaObject $object, &$list)
     {
         foreach ($object->listImportNames() as $parent) {
             if (array_key_exists($parent, $list)) {
