@@ -2,22 +2,29 @@
 
 namespace Icinga\Module\Director\Objects;
 
-use Icinga\Exception\IcingaException;
+use Icinga\Exception\NotFoundError;
+use Icinga\Module\Director\Daemon\Logger;
 use Icinga\Module\Director\Data\Db\DbObjectWithSettings;
+use Icinga\Module\Director\Db;
+use Icinga\Module\Director\DirectorObject\Automation\ExportInterface;
+use Icinga\Module\Director\Exception\DuplicateKeyException;
 use Icinga\Module\Director\Hook\JobHook;
 use Exception;
+use InvalidArgumentException;
 
-class DirectorJob extends DbObjectWithSettings
+class DirectorJob extends DbObjectWithSettings implements ExportInterface
 {
     /** @var JobHook */
     protected $job;
 
     protected $table = 'director_job';
 
-    protected $keyName = 'id';
+    protected $keyName = 'job_name';
 
     protected $autoincKeyName = 'id';
 
+    protected $protectAutoinc = false;
+
     protected $defaultProperties = [
         'id'                     => null,
         'job_name'               => null,
@@ -42,13 +49,18 @@ class DirectorJob extends DbObjectWithSettings
 
     protected $settingsRemoteId = 'job_id';
 
+    public function getUniqueIdentifier()
+    {
+        return $this->get('job_name');
+    }
+
     /**
      * @return JobHook
      */
     public function job()
     {
         if ($this->job === null) {
-            $class = $this->job_class;
+            $class = $this->get('job_class');
             $this->job = new $class;
             $this->job->setDb($this->connection);
             $this->job->setDefinition($this);
@@ -58,31 +70,34 @@ class DirectorJob extends DbObjectWithSettings
     }
 
     /**
-     * @throws IcingaException
+     * @throws \Icinga\Module\Director\Exception\DuplicateKeyException
      */
     public function run()
     {
         $job = $this->job();
-        $this->ts_last_attempt = date('Y-m-d H:i:s');
+        $this->set('ts_last_attempt', date('Y-m-d H:i:s'));
 
         try {
             $job->run();
-            $this->last_attempt_succeeded = 'y';
+            $this->set('last_attempt_succeeded', 'y');
+            $success = true;
         } catch (Exception $e) {
-            $this->ts_last_error = date('Y-m-d H:i:s');
-            $this->last_error_message = $e->getMessage();
-            $this->last_attempt_succeeded = 'n';
+            Logger::error($e->getMessage());
+            $this->set('ts_last_error', date('Y-m-d H:i:s'));
+            $this->set('last_error_message', $e->getMessage());
+            $this->set('last_attempt_succeeded', 'n');
+            $success = false;
         }
 
         if ($this->hasBeenModified()) {
             $this->store();
         }
+
+        return $success;
     }
 
     /**
      * @return bool
-     * @throws IcingaException
-     * @throws \Icinga\Exception\NotFoundError
      */
     public function shouldRun()
     {
@@ -91,8 +106,6 @@ class DirectorJob extends DbObjectWithSettings
 
     /**
      * @return bool
-     * @throws IcingaException
-     * @throws \Icinga\Exception\NotFoundError
      */
     public function isOverdue()
     {
@@ -101,27 +114,25 @@ class DirectorJob extends DbObjectWithSettings
         }
 
         return (
-            strtotime($this->ts_last_attempt) + $this->run_interval * 2
+            strtotime($this->get('ts_last_attempt')) + $this->get('run_interval') * 2
         ) < time();
     }
 
     public function hasBeenDisabled()
     {
-        return $this->disabled === 'y';
+        return $this->get('disabled') === 'y';
     }
 
     /**
      * @return bool
-     * @throws IcingaException
-     * @throws \Icinga\Exception\NotFoundError
      */
     public function isPending()
     {
-        if ($this->ts_last_attempt === null) {
+        if ($this->get('ts_last_attempt') === null) {
             return $this->isWithinTimeperiod();
         }
 
-        if (strtotime($this->ts_last_attempt) + $this->run_interval < time()) {
+        if (strtotime($this->get('ts_last_attempt')) + $this->get('run_interval') < time()) {
             return $this->isWithinTimeperiod();
         }
 
@@ -130,8 +141,6 @@ class DirectorJob extends DbObjectWithSettings
 
     /**
      * @return bool
-     * @throws IcingaException
-     * @throws \Icinga\Exception\NotFoundError
      */
     public function isWithinTimeperiod()
     {
@@ -144,25 +153,30 @@ class DirectorJob extends DbObjectWithSettings
 
     public function lastAttemptSucceeded()
     {
-        return $this->last_attempt_succeeded === 'y';
+        return $this->get('last_attempt_succeeded') === 'y';
+    }
+
+    public function lastAttemptFailed()
+    {
+        return $this->get('last_attempt_succeeded') === 'n';
     }
 
     public function hasTimeperiod()
     {
-        return $this->timeperiod_id !== null;
+        return $this->get('timeperiod_id') !== null;
     }
 
     /**
      * @param $timeperiod
      * @return $this
-     * @throws IcingaException
+     * @throws \Icinga\Exception\NotFoundError
      */
     public function setTimeperiod($timeperiod)
     {
         if (is_string($timeperiod)) {
             $timeperiod = IcingaTimePeriod::load($timeperiod, $this->connection);
         } elseif (! $timeperiod instanceof IcingaTimePeriod) {
-            throw new IcingaException('TimePeriod expected');
+            throw new InvalidArgumentException('TimePeriod expected');
         }
 
         $this->set('timeperiod_id', $timeperiod->get('id'));
@@ -172,9 +186,7 @@ class DirectorJob extends DbObjectWithSettings
 
     /**
      * @return object
-     * @throws IcingaException
      * @throws \Icinga\Exception\NotFoundError
-     * @throws \Icinga\Exception\ProgrammingError
      */
     public function export()
     {
@@ -194,13 +206,83 @@ class DirectorJob extends DbObjectWithSettings
         return $plain;
     }
 
+    /**
+     * @param $plain
+     * @param Db $db
+     * @param bool $replace
+     * @return DirectorJob
+     * @throws DuplicateKeyException
+     * @throws NotFoundError
+     */
+    public static function import($plain, Db $db, $replace = false)
+    {
+        $dummy = new static;
+        $idCol = $dummy->autoincKeyName;
+        $keyCol = $dummy->keyName;
+        $properties = (array) $plain;
+        if (isset($properties['originalId'])) {
+            $id = $properties['originalId'];
+            unset($properties['originalId']);
+        } else {
+            $id = null;
+        }
+        $name = $properties[$keyCol];
+
+        if ($replace && static::existsWithNameAndId($name, $id, $db)) {
+            $object = static::loadWithAutoIncId($id, $db);
+        } elseif ($replace && static::exists($name, $db)) {
+            $object = static::load($name, $db);
+        } elseif (static::exists($name, $db)) {
+            throw new DuplicateKeyException(
+                'Director Job "%s" already exists',
+                $name
+            );
+        } else {
+            $object = static::create([], $db);
+        }
+
+        $object->setProperties($properties);
+        if ($id !== null) {
+            $object->reallySet($idCol, $id);
+        }
+
+        return $object;
+    }
+
+    /**
+     * @param string $name
+     * @param int $id
+     * @param Db $connection
+     * @api internal
+     * @return bool
+     */
+    protected static function existsWithNameAndId($name, $id, Db $connection)
+    {
+        $db = $connection->getDbAdapter();
+        $dummy = new static;
+        $idCol = $dummy->autoincKeyName;
+        $keyCol = $dummy->keyName;
+
+        return (string) $id === (string) $db->fetchOne(
+            $db->select()
+                ->from($dummy->table, $idCol)
+                ->where("$idCol = ?", $id)
+                ->where("$keyCol = ?", $name)
+        );
+    }
+
     /**
      * @return IcingaTimePeriod
-     * @throws IcingaException
-     * @throws \Icinga\Exception\NotFoundError
      */
     protected function timeperiod()
     {
-        return IcingaTimePeriod::loadWithAutoIncId($this->timeperiod_id, $this->connection);
+        try {
+            return IcingaTimePeriod::loadWithAutoIncId($this->get('timeperiod_id'), $this->connection);
+        } catch (NotFoundError $e) {
+            throw new \RuntimeException(sprintf(
+                'The TimePeriod configured for Job "%s" could not have been found',
+                $this->get('name')
+            ));
+        }
     }
 }
