@@ -5,6 +5,8 @@ namespace Icinga\Module\Director\Objects;
 use Icinga\Application\Benchmark;
 use Icinga\Data\Filter\Filter;
 use Icinga\Module\Director\Db;
+use Icinga\Module\Director\Db\IcingaObjectFilterHelper;
+use Icinga\Module\Director\Repository\IcingaTemplateRepository;
 use InvalidArgumentException;
 use LogicException;
 use Zend_Db_Select as ZfSelect;
@@ -39,9 +41,15 @@ abstract class GroupMembershipResolver
     /** @var IcingaObjectGroup[] */
     protected $groups = array();
 
+    /** @var array */
+    protected $staticGroups = array();
+
     /** @var bool */
     protected $deferred = false;
 
+    /** @var bool */
+    protected $checked = false;
+
     /** @var bool */
     protected $useTransactions = false;
 
@@ -62,6 +70,32 @@ abstract class GroupMembershipResolver
         return $this->clearGroups()->clearObjects()->refreshDb(true);
     }
 
+    public function checkDb()
+    {
+        if ($this->checked) {
+            return $this;
+        }
+
+        if ($this->isDeferred()) {
+            // ensure we are not working with cached data
+            IcingaTemplateRepository::clear();
+        }
+
+        Benchmark::measure('Rechecking all objects');
+        $this->recheckAllObjects($this->getAppliedGroups());
+        if (empty($this->objects) && empty($this->groups)) {
+            Benchmark::measure('Nothing to check, got no qualified object');
+            return $this;
+        }
+
+        Benchmark::measure('Recheck done, loading existing mappings');
+        $this->fetchStoredMappings();
+        Benchmark::measure('Got stored group mappings');
+
+        $this->checked = true;
+        return $this;
+    }
+
     /**
      * @param bool $force
      * @return $this
@@ -70,13 +104,18 @@ abstract class GroupMembershipResolver
     public function refreshDb($force = false)
     {
         if ($force || ! $this->isDeferred()) {
-            Benchmark::measure('Going to refresh all group mappings');
-            $this->fetchStoredMappings();
-            Benchmark::measure('Got stored HG mappings, rechecking all objects');
-            $this->recheckAllObjects($this->getAppliedGroups());
+            $this->checkDb();
+
+            if (empty($this->objects) && empty($this->groups)) {
+                Benchmark::measure('Nothing to check, got no qualified object');
+
+                return $this;
+            }
+
             Benchmark::measure('Ready, going to store new mappings');
             $this->storeNewMappings();
             $this->removeOutdatedMappings();
+            Benchmark::measure('Updated group mappings in db');
         }
 
         return $this;
@@ -140,7 +179,12 @@ abstract class GroupMembershipResolver
             $this->objects = [];
         }
 
-        $this->objects[$id] = $object;
+        if ($object->isTemplate()) {
+            $this->includeChildObjects($object);
+        } else {
+            $this->objects[$id] = $object;
+        }
+
         return $this;
     }
 
@@ -157,6 +201,26 @@ abstract class GroupMembershipResolver
         return $this;
     }
 
+    protected function includeChildObjects(IcingaObject $object)
+    {
+        $query = $this->db->select()
+            ->from(['o' => $object->getTableName()])
+            ->where('o.object_type = ?', 'object');
+
+        IcingaObjectFilterHelper::filterByTemplate(
+            $query,
+            $object,
+            'o',
+            Db\IcingaObjectFilterHelper::INHERIT_DIRECT_OR_INDIRECT
+        );
+
+        foreach ($object::loadAll($this->connection, $query) as $child) {
+            $this->objects[$child->getProperty('id')] = $child;
+        }
+
+        return $this;
+    }
+
     /**
      * @param IcingaObject $object
      * @return $this
@@ -193,10 +257,9 @@ abstract class GroupMembershipResolver
     public function addGroup(IcingaObjectGroup $group)
     {
         $this->assertBeenLoadedFromDb($group);
+        $this->groups[$group->get('id')] = $group;
 
-        if ($group->get('assign_filter') !== null) {
-            $this->groups[$group->get('id')] = $group;
-        }
+        $this->checked = false;
 
         return $this;
     }
@@ -211,6 +274,8 @@ abstract class GroupMembershipResolver
             $this->addGroup($group);
         }
 
+        $this->checked = false;
+
         return $this;
     }
 
@@ -240,15 +305,25 @@ abstract class GroupMembershipResolver
     public function clearGroups()
     {
         $this->objects = array();
+        $this->checked = false;
         return $this;
     }
 
+    public function getNewMappings()
+    {
+        if ($this->newMappings !== null && $this->existingMappings !== null) {
+            return $this->getDifference($this->newMappings, $this->existingMappings);
+        } else {
+            return [];
+        }
+    }
+
     /**
      * @throws \Zend_Db_Adapter_Exception
      */
     protected function storeNewMappings()
     {
-        $diff = $this->getDifference($this->newMappings, $this->existingMappings);
+        $diff = $this->getNewMappings();
         $count = count($diff);
         if ($count === 0) {
             return;
@@ -274,25 +349,35 @@ abstract class GroupMembershipResolver
 
     protected function getGroupId($name)
     {
+        $type = $this->type;
         if ($this->groupMap === null) {
             $this->groupMap = $this->db->fetchPairs(
-                $this->db->select()->from('icinga_hostgroup', ['object_name', 'id'])
+                $this->db->select()->from("icinga_${type}group", ['object_name', 'id'])
             );
         }
 
         if (array_key_exists($name, $this->groupMap)) {
             return $this->groupMap[$name];
         } else {
-            throw new InvalidArgumentException(
+            throw new InvalidArgumentException(sprintf(
                 'Unable to lookup the group name for "%s"',
                 $name
-            );
+            ));
+        }
+    }
+
+    public function getOutdatedMappings()
+    {
+        if ($this->newMappings !== null && $this->existingMappings !== null) {
+            return $this->getDifference($this->existingMappings, $this->newMappings);
+        } else {
+            return [];
         }
     }
 
     protected function removeOutdatedMappings()
     {
-        $diff = $this->getDifference($this->existingMappings, $this->newMappings);
+        $diff = $this->getOutdatedMappings();
         $count = count($diff);
         if ($count === 0) {
             return;
@@ -321,7 +406,7 @@ abstract class GroupMembershipResolver
         );
     }
 
-    protected function getDifference(& $left, & $right)
+    protected function getDifference(&$left, &$right)
     {
         $diff = array();
 
@@ -364,8 +449,14 @@ abstract class GroupMembershipResolver
                 'object_id' => "${type}_id",
             )
         );
+
         $this->addMembershipWhere($query, "${type}_id", $this->objects);
         $this->addMembershipWhere($query, "${type}group_id", $this->groups);
+        if (! empty($this->groups)) {
+            // load staticGroups (we touched here) additionally, so we can compare changes
+            $this->addMembershipWhere($query, "${type}group_id", $this->staticGroups);
+        }
+
         foreach ($this->db->fetchAll($query) as $row) {
             $groupId = $row->group_id;
             $objectId = $row->object_id;
@@ -382,18 +473,24 @@ abstract class GroupMembershipResolver
     /**
      * @param ZfSelect $query
      * @param string $column
-     * @param IcingaObject[] $objects
+     * @param IcingaObject[]|int[] $objects
      * @return ZfSelect
      */
-    protected function addMembershipWhere(ZfSelect $query, $column, & $objects)
+    protected function addMembershipWhere(ZfSelect $query, $column, &$objects)
     {
         if (empty($objects)) {
             return $query;
         }
 
         $ids = array();
-        foreach ($objects as $object) {
-            $ids[] = (int) $object->get('id');
+        foreach ($objects as $k => $object) {
+            if (is_int($object)) {
+                $ids[] = $k;
+            } elseif (is_string($object)) {
+                $ids[] = (int) $object;
+            } else {
+                $ids[] = (int) $object->get('id');
+            }
         }
 
         if (count($ids) === 1) {
@@ -407,7 +504,8 @@ abstract class GroupMembershipResolver
 
     protected function recheckAllObjects($groups)
     {
-        $mappings = array();
+        $mappings = [];
+        $staticGroups = [];
 
         if ($this->objects === null) {
             $objects = $this->fetchAllObjects();
@@ -424,22 +522,22 @@ abstract class GroupMembershipResolver
             if ($object->isTemplate()) {
                 continue;
             }
+
             $mt = microtime(true);
             $id = $object->get('id');
 
-            // TODO: fix this last hard host dependency
-            $resolver = HostApplyMatches::prepare($object);
+            DynamicApplyMatches::setType($this->type);
+            $resolver = DynamicApplyMatches::prepare($object);
             foreach ($groups as $groupId => $filter) {
                 if ($resolver->matchesFilter($filter)) {
                     if (! array_key_exists($groupId, $mappings)) {
                         $mappings[$groupId] = [];
                     }
-
                     $mappings[$groupId][$id] = $id;
                 }
             }
 
-
+            // can only be run reliably when updating for all groups
             $groupNames = $object->get('groups');
             if (empty($groupNames)) {
                 $groupNames = $object->listInheritedGroupNames();
@@ -451,6 +549,7 @@ abstract class GroupMembershipResolver
                 }
 
                 $mappings[$groupId][$id] = $id;
+                $staticGroups[$groupId] = $groupId;
             }
 
             $times[] = (microtime(true) - $mt) * 1000;
@@ -465,7 +564,8 @@ abstract class GroupMembershipResolver
         }
 
         Benchmark::measure(sprintf(
-            'Hostgroup apply recalculated: objects=%d groups=%d min=%d max=%d avg=%d (in ms)',
+            '%sgroup apply recalculated: objects=%d groups=%d min=%d max=%d avg=%d (in ms)',
+            $this->type,
             $count,
             count($groups),
             $min,
@@ -473,13 +573,10 @@ abstract class GroupMembershipResolver
             $avg
         ));
 
-        foreach ($this->fetchMissingSingleAssignments() as $row) {
-            $mappings[$row->group_id][$row->object_id] = $row->object_id;
-        }
-
         Benchmark::measure('Done with single assignments');
 
         $this->newMappings = $mappings;
+        $this->staticGroups = $staticGroups;
     }
 
     protected function getAppliedGroups()
@@ -510,7 +607,7 @@ abstract class GroupMembershipResolver
                 'id',
                 'assign_filter',
             )
-        )->where('assign_filter IS NOT NULL');
+        )->where("assign_filter IS NOT NULL AND assign_filter != ''");
 
         return $this->parseFilters($this->db->fetchPairs($query));
     }
@@ -529,30 +626,6 @@ abstract class GroupMembershipResolver
         }, $list);
     }
 
-    protected function fetchMissingSingleAssignments()
-    {
-        $type = $this->getType();
-        $query = $this->db->select()->from(
-            array("go" => $this->getTableName()),
-            array(
-                'object_id' => "${type}_id",
-                'group_id'  => "${type}group_id",
-            )
-        )->joinLeft(
-            array("gor" => $this->getResolvedTableName()),
-            "go.${type}_id = gor.${type}_id AND go.${type}group_id = gor.${type}group_id",
-            array()
-        );
-
-        $this->addMembershipWhere($query, "go.${type}_id", $this->objects);
-        $this->addMembershipWhere($query, "go.${type}group_id", $this->groups);
-
-        // Order matters, this must be AND:
-        $query->where("gor.${type}_id IS NULL");
-
-        return $this->db->fetchAll($query);
-    }
-
     protected function getTableName()
     {
         $type = $this->getType();
