@@ -355,14 +355,23 @@ class IcingaService extends IcingaObject implements ExportInterface
         $this->set('object_type', 'object');
 
         foreach ($this->mapHostsToZones($hostnames) as $zone => $names) {
-            $this->set('host_id', $names);
-
             $blacklisted = $this->getBlacklistedHostnames();
             $zoneNames = array_diff($names, $blacklisted);
+
+            $disabled = [];
+            foreach ($zoneNames as $name) {
+                if (IcingaHost::load($name, $this->getConnection())->isDisabled()) {
+                    $disabled[] = $name;
+                }
+            }
+            $zoneNames = array_diff($zoneNames, $disabled);
+
             if (empty($zoneNames)) {
                 continue;
             }
 
+            $this->set('host_id', $zoneNames);
+
             $config->configFile('director/' . $zone . '/service_apply', '.cfg')
                 ->addLegacyObject($this);
         }
@@ -471,14 +480,24 @@ class IcingaService extends IcingaObject implements ExportInterface
 
     /**
      * @return string
+     * @throws \Icinga\Exception\NotFoundError
+     * @throws \Icinga\Module\Director\Exception\NestingError
      */
     protected function renderSuffix()
     {
-        if ($this->isApplyRule() || $this->usesVarOverrides()) {
-            return $this->renderImportHostVarOverrides() . parent::renderSuffix();
-        } else {
-            return parent::renderSuffix();
+        $suffix = '';
+        if ($this->isApplyRule()) {
+            $zoneName = $this->getRenderingZone();
+            if (!IcingaZone::zoneNameIsGlobal($zoneName, $this->connection)) {
+                $suffix .= c::renderKeyValue('zone', c::renderString($zoneName));
+            }
         }
+
+        if ($this->isApplyRule() || $this->usesVarOverrides()) {
+            $suffix .= $this->renderImportHostVarOverrides();
+        }
+
+        return $suffix . parent::renderSuffix();
     }
 
     /**
