@@ -2,38 +2,32 @@
 
 namespace Icinga\Module\Director\Web\Form\Validate;
 
-use Icinga\Data\Filter\FilterMatch;
+use Icinga\Module\Director\Restriction\MatchingFilter;
 use Zend_Validate_Abstract;
 
 class NamePattern extends Zend_Validate_Abstract
 {
     const INVALID = 'intInvalid';
 
-    private $pattern;
-
     private $filter;
 
     public function __construct($pattern)
     {
-        $this->pattern = $pattern;
-        $this->_messageTemplates[self::INVALID] = sprintf(
-            'Does not match %s',
-            $pattern
-        );
-    }
-
-    protected function matches($value)
-    {
-        if ($this->filter === null) {
-            $this->filter = new FilterMatch('prop', '=', $this->pattern);
+        if (! is_array($pattern)) {
+            $pattern = [$pattern];
         }
 
-        return $this->filter->matches($value);
+        $this->filter = MatchingFilter::forPatterns($pattern, 'value');
+
+        $this->_messageTemplates[self::INVALID] = sprintf(
+            'Does not match %s',
+            (string) $this->filter
+        );
     }
 
     public function isValid($value)
     {
-        if ($this->matches((object) ['prop' => $value])) {
+        if ($this->filter->matches((object) ['value' => $value])) {
             return true;
         } else {
             $this->_error(self::INVALID, $value);
